@@ -267,7 +267,7 @@ def edit(save_location, haystack):
     main(save_location, haystack, editing=True)
 
 def main(save_location, needle=r"C:\Users\Toto\Documents\AdAstraIndustries\aai_engine\img\cv.png", editing=False):
-    temp_screenshot = tempfile.NamedTemporaryFile(suffix='.png')
+    temp_screenshot = tempfile.NamedTemporaryFile(suffix='.png', delete=False)
     temp_screenshot_path = temp_screenshot.name
     if os.name == "posix":
         temp_screenshot_path = temp_screenshot_path.split(".")[0] + "_000.png"
@@ -296,6 +296,8 @@ def main(save_location, needle=r"C:\Users\Toto\Documents\AdAstraIndustries\aai_e
         app = ScreenShotTaker(root, save_location, haystack=temp_screenshot_path, editing=False)
 
     root.mainloop()
+    temp_screenshot.close()
+    os.unlink(temp_screenshot.name)
 
 class AAIWindow():
 
@@ -360,5 +362,4 @@ def take_screenshot_save(save_location):
     # time.sleep(3)
     save_path = ''.join([save_location, "/img/aai_", ''.join(choice(digits) for i in range(12)), ".png"])
     im = pyautogui.screenshot(save_path)
-    print("Done")
-
+    print("Done")
\ No newline at end of file
